# What's Changed

1. ✨ 新增: 支持接入飞书（Lark）。支持飞书文字、图片。
2. ✨ 新增: 添加月之暗面配置模板 #446
3. ✨ 新增: Gewechat 支持文件输出
4. 🐛 修复: 修复gewechat无法at人和发语音失败的问题 #447 #438
5. 🐛 修复: 修复qq在@和回复开启的情况下转发消息异常的问题
6. 🐛 修复: GitHub 加速镜像没有正确被应用
7. 🐛 优化: 平台将显示不受支持的消息段